summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorPavel Březina <pbrezina@redhat.com>2015-10-07 14:16:38 +0200
committerJakub Hrozek <jhrozek@redhat.com>2015-10-08 20:52:06 +0200
commitf106125bbd8f038a93d3fabe36899391c215f937 (patch)
tree73720932fb5e84d9bf5e85c9bf15900e09448ec7
parent046b063e73e6f2a1bb0e2e1e654ed777b5276edc (diff)
downloadsssd-f106125bbd8f038a93d3fabe36899391c215f937.tar.gz
sssd-f106125bbd8f038a93d3fabe36899391c215f937.tar.xz
sssd-f106125bbd8f038a93d3fabe36899391c215f937.zip
intg: fix typos
Reviewed-by: Pavel Reichl <preichl@redhat.com>
-rw-r--r--src/tests/intg/sssd_id.py16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/tests/intg/sssd_id.py b/src/tests/intg/sssd_id.py
index 45f2822b5..500f242ec 100644
--- a/src/tests/intg/sssd_id.py
+++ b/src/tests/intg/sssd_id.py
@@ -24,7 +24,7 @@ from ctypes import (cdll, c_int, c_char, c_uint32, c_long, c_char_p,
class NssReturnCode(object):
- """ 'enum' class for name service switch retrn code """
+ """ 'enum' class for name service switch return code """
TRYAGAIN = -2,
UNAVAIL = -1
NOTFOUND = 0
@@ -42,8 +42,8 @@ def call_sssd_initgroups(user, gid):
@param int gid the additional gid will be also added to the list.
@return (int, int, List[int]) (err, errno, gids)
gids shoudl contain user group IDs if err is NssReturnCode.SUCCESS
otherwise errno will contain non-zero vlaue.
"""
libnss_sss_path = config.PREFIX + "/lib/libnss_sss.so.2"
libnss_sss = cdll.LoadLibrary(libnss_sss_path)
@@ -67,7 +67,7 @@ def call_sssd_initgroups(user, gid):
gids = []
if res == NssReturnCode.SUCCESS:
gids_count = size[0]
- assert gids_count > 0, "_nss_sss_initgroups_dyn shoulld return " \
+ assert gids_count > 0, "_nss_sss_initgroups_dyn should return " \
"one gid"
for i in range(0, gids_count):
@@ -85,8 +85,8 @@ def get_user_gids(user):
@param string user name of user
@return (int, int, List[int]) (err, errno, gids)
gids shoudl contain user group IDs if err is NssReturnCode.SUCCESS
otherwise errno will contain non-zero vlaue.
"""
pwd_user = pwd.getpwnam(user)
uid = pwd_user.pw_uid
@@ -106,9 +106,9 @@ def get_user_groups(user):
@param string user name of user
@return (int, int, List[string]) (err, errno, groups)
roups shoudl contain names of user groups
if err is NssReturnCode.SUCCESS
- otherwise errno will contain non-zero vlaue.
+ otherwise errno will contain non-zero value.
"""
(res, errno, gids) = get_user_gids(user)
groups = []
@@ -42,8 +42,8 @@ def call_sssd_initgroups(user, gid):
- gids shoudl contain user group IDs if err is NssReturnCode.SUCCESS
- otherwise errno will contain non-zero vlaue.
+ gids should contain user group IDs if err is NssReturnCode.SUCCESS
+ otherwise errno will contain non-zero value.
"""
libnss_sss_path = config.PREFIX + "/lib/libnss_sss.so.2"
@@ -85,8 +85,8 @@ def get_user_gids(user):
- gids shoudl contain user group IDs if err is NssReturnCode.SUCCESS
- otherwise errno will contain non-zero vlaue.
+ gids should contain user group IDs if err is NssReturnCode.SUCCESS
+ otherwise errno will contain non-zero value.
"""
pwd_user = pwd.getpwnam(user)
@@ -106,9 +106,9 @@ def get_user_groups(user):
- roups shoudl contain names of user groups
+ groups should contain names of user groups
if err is NssReturnCode.SUCCESS